@@ -37,6 +37,7 @@ from making_with_code_cli.cli_setup import (
     InstallTree,
     InstallAtom,
     InstallImageMagick,
+    InstallHttpie,
     GHAuthentication,
     GitConfiguration,
 )
@@ -101,6 +102,7 @@ def setup(ctx, yes, teacher):
         InstallTree(settings),
         InstallAtom(settings),
         InstallImageMagick(settings),
+        InstallHttpie(settings),
         GHAuthentication(settings),
         GitConfiguration(settings),
     ]
